/* Dali Clock - a melting digital clock for PalmOS.
 * Copyright (c) 1991-2007 Jamie Zawinski <jwz@jwz.org>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  No representations are made about the suitability of this
 * software for any purpose.  It is provided "as is" without express or
 * implied warranty.
 */

#ifndef __NUMBERS_H__
#define __NUMBERS_H__

typedef unsigned short POS;

struct raw_number {
  const unsigned char *bits;
  POS width, height;
};

struct raw_number *get_raw_number_0 (void);
struct raw_number *get_raw_number_1 (void);
struct raw_number *get_raw_number_2 (void);
struct raw_number *get_raw_number_3 (void);

#endif /* __NUMBERS_H__ */
